@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -26,7 +27,7 @@ EdgeMap<Dir,double> edge_lengths(const Graph<Dir>& G, const GenericMatrix<Matrix
 {
    EdgeMap<Dir,double> L(G);
    Matrix<double> C(coords);
-   for (typename Entire< Edges< Graph<Dir> > >::const_iterator e_it=entire(edges(G)); !e_it.at_end(); ++e_it)
+   for (auto e_it=entire(edges(G)); !e_it.at_end(); ++e_it)
       L[*e_it]=std::sqrt(sqr(C[e_it.from_node()]-C[e_it.to_node()]));
 
    return L;
@@ -35,14 +36,14 @@ EdgeMap<Dir,double> edge_lengths(const Graph<Dir>& G, const GenericMatrix<Matrix
 UserFunctionTemplate4perl("# @category Other"
 			  "# Compute the lengths of all edges of a given graph //G// from"
 			  "# the coordinates //coords// of its nodes."
-			  "# @param props::Graph<Directed> G the input graph"
+			  "# @param GraphAdjacency<Directed> G the input graph"
 			  "# @param Matrix coords the coordinates of the nodes"
 			  "# @return EdgeMap"
 			  "# @example [application polytope] The following prints the edge length of the complete graph with 3 nodes"
 			  "# and edge lengths given by the coordiantes of the standard 2-simplex:"
            "# > print edge_lengths(complete(3)->ADJACENCY,simplex(2)->VERTICES);"
            "# | 1 1 1.414213562",
-			  "edge_lengths(props::Graph Matrix)");
+			  "edge_lengths(GraphAdjacency Matrix)");
 } }
 
 // Local Variables:
