@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -56,6 +56,6 @@ namespace polymake { namespace graph {
 
    FunctionTemplate4perl("migrate_hasse_properties<SeqType>(Lattice<BasicDecoration, SeqType>)");
 
-   FunctionTemplate4perl("faces_map_from_decoration(props::Graph, NodeMap)");
+   FunctionTemplate4perl("faces_map_from_decoration(GraphAdjacency, NodeMap)");
 
 }}
