@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_POLYTOPE_SEPARATING_HYPERPLANE_H
-#define POLYMAKE_POLYTOPE_SEPARATING_HYPERPLANE_H
+#pragma once
 
 #include "polymake/Vector.h"
 #include "polymake/Matrix.h"
@@ -58,7 +57,6 @@ Vector<Scalar> separating_hyperplane(const GenericVector<VectorType, Scalar>& q,
 
 }}
 
-#endif
 
 // Local Variables:
 // mode:C++
