@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -22,20 +23,20 @@
 namespace polymake { namespace polytope {
 
 template <typename Scalar>
-perl::Object center(perl::Object p_in)
+BigObject center(BigObject p_in)
 {
    // read some point in the relative interior
    const Vector<Scalar> point=p_in.give("REL_INT_POINT");
-   const int d = point.dim();
+   const Int d = point.dim();
 
    // check if point is affine
    if (is_zero(point[0]))
       throw std::runtime_error("relative interior point not affine");
 
    SparseMatrix<Scalar> tau=unit_matrix<Scalar>(d);
-   tau[0].slice(1)=-point.slice(1);
+   tau[0].slice(range_from(1)) = -point.slice(range_from(1));
 
-   perl::Object p_out=transform<Scalar>(p_in, tau);
+   BigObject p_out=transform<Scalar>(p_in, tau);
    p_out.set_description() << "Centered polytope transformed from " << p_in.name() << endl;
 
    p_out.take("CENTERED") << true;
@@ -52,11 +53,11 @@ UserFunctionTemplate4perl("# @category Transformations"
                           "# > $P = new Polytope(VERTICES => [[1,1,1],[1,2,1],[1,1,2]]);"
                           "# > $origin = new Vector([1,0,0]);"
                           "# > print $P->contains_in_interior($origin);"
-                          "# | "
+                          "# | false"
                           "# To create a translate that contains the origin, do this:"
                           "# > $PC = center($P);"
                           "# > print $PC->contains_in_interior($origin);"
-                          "# | 1"
+                          "# | true"
                           "# This is what happened to the vertices:"
                           "# > print $PC->VERTICES;"
                           "# | 1 -1/3 -1/3"
@@ -64,7 +65,7 @@ UserFunctionTemplate4perl("# @category Transformations"
                           "# | 1 -1/3 2/3"
                           "# There also exists a property to check whether a polytope is centered:"
                           "# > print $PC->CENTERED;"
-                          "# | 1",
+                          "# | true",
                           "center<Scalar> (Polytope<Scalar>)");
 } }
 
