@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -23,10 +24,10 @@ namespace polymake { namespace topaz {
   
 namespace {
 
-void combinatorial_k_skeleton_impl(perl::Object p_in, perl::Object& p_out, const int k, perl::OptionSet options)
+void combinatorial_k_skeleton_impl(BigObject p_in, BigObject& p_out, const Int k, OptionSet options)
 {
-   const Array< Set<int> > C = p_in.give("FACETS");
-   const PowerSet<int> Skeleton = k_skeleton(C,k);
+   const Array<Set<Int>> C = p_in.give("FACETS");
+   const PowerSet<Int> Skeleton = k_skeleton(C,k);
    
    p_out.set_description() << k << "-skeleton of " << p_in.name() << endl;
    p_out.take("FACETS") << Skeleton;
@@ -38,17 +39,17 @@ void combinatorial_k_skeleton_impl(perl::Object p_in, perl::Object& p_out, const
 }
 
 
-perl::Object combinatorial_k_skeleton(perl::Object p_in, const int k, perl::OptionSet options)
+BigObject combinatorial_k_skeleton(BigObject p_in, const Int k, OptionSet options)
 {
-   perl::Object p_out("SimplicialComplex");
+   BigObject p_out("SimplicialComplex");
    combinatorial_k_skeleton_impl(p_in, p_out, k, options);
    return p_out;
 }
 
 template <typename Scalar>
-perl::Object k_skeleton(perl::Object p_in, const int k, perl::OptionSet options)
+BigObject k_skeleton(BigObject p_in, const Int k, OptionSet options)
 {
-   perl::Object p_out(perl::ObjectType::construct<Scalar>("topaz::GeometricSimplicialComplex"));
+   BigObject p_out("GeometricSimplicialComplex", mlist<Scalar>());
    combinatorial_k_skeleton_impl(p_in, p_out, k, options);
    
    Matrix<Scalar> GR;
@@ -65,7 +66,10 @@ UserFunction4perl("# @category Producing a new simplicial complex from others\n"
                   "# @param SimplicialComplex complex"
                   "# @param Int k"
                   "# @option Bool no_labels Do not create [[VERTEX_LABELS]]. default: 0"
-                  "# @return SimplicialComplex",
+                  "# @return SimplicialComplex"
+                  "# @example The 2-skeleton of the 3-simplex is its boundary, a 2-sphere:"
+                  "# > print isomorphic(k_skeleton(simplex(3),2), simplex(3)->BOUNDARY);"
+                  "# | true",
                   &combinatorial_k_skeleton, "k_skeleton(SimplicialComplex $ { no_labels=>0 })");
 
 UserFunctionTemplate4perl("# @category Producing a new simplicial complex from others\n"
@@ -73,7 +77,10 @@ UserFunctionTemplate4perl("# @category Producing a new simplicial complex from o
                           "# @param GeometricSimplicialComplex complex"
                           "# @param Int k"
                           "# @option Bool no_labels Do not create [[VERTEX_LABELS]]. default: 0"
-                          "# @return GeometricSimplicialComplex",
+                          "# @return GeometricSimplicialComplex"
+                          "# @example The 2-skeleton of the 3-ball is its boundary, a 2-sphere:"
+                          "# > print isomorphic(k_skeleton(ball(3),2), ball(3)->BOUNDARY);"
+                          "# | true",
                           "k_skeleton<Scalar>(GeometricSimplicialComplex<Scalar> $ { no_labels=>0 })");
 } }
 
