@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -18,12 +19,13 @@
 #include "polymake/Array.h"
 #include "polymake/PowerSet.h"
 #include "polymake/FacetList.h"
+#include "polymake/topaz/lawler.h"
 
 namespace polymake { namespace topaz {
   
-Array<Set<int>> lawler(const Array<Set<int> > F, const int n_vertices )
+Array<Set<Int>> lawler(const Array<Set<Int>>& F, const Int n_vertices)
 {
-   sequence Vertices(0,n_vertices);
+   sequence Vertices(0, n_vertices);
 
    // C stores the candidates for minimal non-faces
    // insert every single element in the complement of the first facet
@@ -31,21 +33,21 @@ Array<Set<int>> lawler(const Array<Set<int> > F, const int n_vertices )
    FacetList C=all_subsets_of_1(Vertices-F[0]);
 
    // incrementally insert the facets into the complex (skip the first facet)
-   Entire< Array< Set<int> > >::const_iterator f=entire(F);
+   auto f = entire(F);
    for (++f; !f.at_end(); ++f) {
-      Set<int> V = Vertices-*f;    // compute the complement of the current facet
+      Set<Int> V = Vertices-*f;    // compute the complement of the current facet
       FacetList Cnew(n_vertices);
       // for every element in C
-      for (Entire<FacetList>::const_iterator cit=entire(C); !cit.at_end(); ++cit) {
+      for (auto cit=entire(C); !cit.at_end(); ++cit) {
 
          // and every vertex in the complement of the facet
-         for (Entire< Set<int> >::const_iterator vit=entire(V); !vit.at_end(); ++vit)
+         for (auto vit=entire(V); !vit.at_end(); ++vit)
             Cnew.replaceMin(*cit + *vit);
       }
       C = Cnew;
    }
 
-   return Array<Set<int>>(C);
+   return Array<Set<Int>>(C);
 }
 
 Function4perl(&lawler, "lawler_minimal_non_faces(Array<Set<Int>>, $)");
