@@ -18,7 +18,7 @@
 	Copyright (C) 2011 - 2015, Simon Hampe <simon.hampe@googlemail.com>
 
 	---
-	Copyright (c) 2016-2020
+	Copyright (c) 2016-2021
 	Ewgenij Gawrilow, Michael Joswig, and the polymake team
 	Technische Universität Berlin, Germany
 	https://polymake.org
@@ -27,8 +27,7 @@
    Moebius function.
 	*/
 
-#ifndef POLYMAKE_ATINT_CYCLIC_CHAINS_H
-#define POLYMAKE_ATINT_CYCLIC_CHAINS_H
+#pragma once
 
 #include "polymake/client.h"
 #include "polymake/graph/Lattice.h"
@@ -54,4 +53,3 @@ namespace polymake { namespace tropical {
 
 } }
 
-#endif
