@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -25,6 +25,9 @@
 #define MA
 #define GMP
 extern "C" {
+#ifdef HAVE_LRSDRIVER
+  #include <lrsdriver.h>
+#endif
   #include <lrslib.h>
 }
 #undef positive
