@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,13 +15,13 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_IDEAL_SINGULAR_TERM_ORDER_DATA_H
-#define POLYMAKE_IDEAL_SINGULAR_TERM_ORDER_DATA_H
+#pragma once
 
 #include "polymake/client.h"
 #include "polymake/Polynomial.h"
 
-#include "Singular/libsingular.h"
+#include "polymake/ideal/internal/singularInclude.h"
+#include "polymake/ideal/internal/singularUtils.h"
 
 namespace polymake { 
 namespace ideal {
@@ -33,8 +34,8 @@ typedef typename std::remove_pointer<decltype(ip_sring::order)>::type singular_o
 
 singular_order_type StringToSingularTermOrder(std::string ringOrderName);
 
-template<typename OrderType>
-class SingularTermOrderData_base{
+template <typename OrderType>
+class SingularTermOrderData_base {
 
 protected:
    const OrderType orderData;
@@ -42,15 +43,20 @@ protected:
 
 public:
    // Constructor:
-   SingularTermOrderData_base(const int n_vars, const OrderType& order) : orderData(order), n_vars(n_vars){
-      if(n_vars == 0) 
+   SingularTermOrderData_base(const int n_vars_, const OrderType& order)
+     : orderData(order)
+     , n_vars(n_vars_)
+   {
+      if (n_vars == 0) 
          throw std::runtime_error("Given ring is not a polynomial ring.");
    }
+
    // Comparison:
-   friend bool operator==(const SingularTermOrderData_base<OrderType> &data1, const SingularTermOrderData_base<OrderType> &data2){
-      //return true;
-      return(data1.orderData == data2.orderData);
+   bool operator== (const SingularTermOrderData_base<OrderType>& other)
+   {
+      return orderData == other.orderData;
    }
+
    // Getters:
    // Not depending on template
    int get_ord_size() const;
@@ -64,8 +70,7 @@ public:
 };
 
 template <typename OrderType> 
-class SingularTermOrderData : 
-public SingularTermOrderData_base<OrderType> {
+class SingularTermOrderData : public SingularTermOrderData_base<OrderType> {
 public:
 //   SingularTermOrderData(const Ring<>& r, const OrderType& order) : SingularTermOrderData_base<OrderType>(r,order) {}
 };
@@ -102,18 +107,21 @@ int* SingularTermOrderData_base<OrderType>::get_block1() const {
 // Methods that do depend on template
 
 
-template<typename Scalar> class SingularTermOrderData<Matrix<Scalar> > : public SingularTermOrderData_base<Matrix<Scalar> > {
+template <typename Scalar>
+class SingularTermOrderData<Matrix<Scalar>> : public SingularTermOrderData_base<Matrix<Scalar>> {
 public:
-   SingularTermOrderData(const int n_vars, const Matrix<Scalar>& order) : SingularTermOrderData_base< Matrix<Scalar> >(n_vars,order) {}
+   using SingularTermOrderData_base<Matrix<Scalar>>::SingularTermOrderData_base;
 
-   int get_ord_size() const {
-     return this->orderData.rows()+1;
+   int get_ord_size() const
+   {
+     return safe_cast(this->orderData.rows()+1);
    }
 
-   int* get_block0() const {
+   int* get_block0() const
+   {
       int ord_size = this->get_ord_size();
       int* block0 = (int*)omalloc0((ord_size+2)*sizeof(int));
-      for(int i = 0; i < ord_size; ++i) {
+      for (int i = 0; i < ord_size; ++i) {
         block0[i] = 1;
       }
       block0[ord_size]=0;
@@ -121,7 +129,8 @@ public:
       return block0;
    }
 
-   int* get_block1() const {
+   int* get_block1() const
+   {
       int ord_size = this->get_ord_size();
       int nvars = this->n_vars;
       int* block1 = (int*)omalloc0((ord_size+2)*sizeof(int));
@@ -133,7 +142,8 @@ public:
       return block1;
    }
 
-   singular_order_type* get_ord() const {
+   singular_order_type* get_ord() const
+   {
       int ord_size = this->get_ord_size();
       singular_order_type* ord=(singular_order_type*)omalloc0((ord_size+2)*sizeof(singular_order_type));
       for(int i = 0; i < ord_size-1; ++i) {
@@ -144,7 +154,8 @@ public:
       return ord;
    }
 
-   int** get_wvhdl() const {
+   int** get_wvhdl() const
+   {
       int ord_size = this->get_ord_size();
       int nvars = this->n_vars;
       int** wvhdl=(int**)omalloc0((ord_size+2)*sizeof(int*));
@@ -154,18 +165,20 @@ public:
             wvhdl[i][j] = (int)this->orderData(i,j);
          }
       }
-      wvhdl[ord_size-1]=NULL;
-      wvhdl[ord_size]=NULL;
-      wvhdl[ord_size+1]=NULL;
+      wvhdl[ord_size-1] = nullptr;
+      wvhdl[ord_size] = nullptr;
+      wvhdl[ord_size+1] = nullptr;
       return wvhdl;
    }
 };
 
-template<typename Scalar> class SingularTermOrderData<Vector<Scalar> > : public SingularTermOrderData_base<Vector<Scalar> > {
+template <typename Scalar>
+class SingularTermOrderData<Vector<Scalar>> : public SingularTermOrderData_base<Vector<Scalar> > {
 public:
-   SingularTermOrderData(const int n_vars, const Vector<Scalar>& order) : SingularTermOrderData_base< Vector<Scalar> >(n_vars,order) {}
+   using SingularTermOrderData_base<Vector<Scalar>>::SingularTermOrderData_base;
 
-   singular_order_type* get_ord() const {
+   singular_order_type* get_ord() const
+   {
       int ord_size = this->get_ord_size();
       singular_order_type* ord=(singular_order_type*)omalloc0((ord_size+1)*sizeof(singular_order_type));
       ord[1]=ringorder_c;
@@ -173,7 +186,8 @@ public:
       return ord;
    }
 
-   int** get_wvhdl() const {
+   int** get_wvhdl() const
+   {
       int ord_size = this->get_ord_size();
       int nvars = this->n_vars;
       int** wvhdl=(int**)omalloc0((ord_size+1)*sizeof(int*));
@@ -181,16 +195,18 @@ public:
       for(int i =0; i<nvars; i++){
          wvhdl[0][i] = (int) this->orderData[i];
       }
-      wvhdl[1]=NULL;
-      wvhdl[2]=NULL;
+      wvhdl[1] = nullptr;
+      wvhdl[2] = nullptr;
       return wvhdl;
    }
 };
 
 template<> class SingularTermOrderData<std::string> : public SingularTermOrderData_base<std::string> {
 public:
-   SingularTermOrderData(const int n_vars, const std::string& order) : SingularTermOrderData_base<std::string>(n_vars,order) {}
-   singular_order_type* get_ord() const {
+   using SingularTermOrderData_base<std::string>::SingularTermOrderData_base;
+
+   singular_order_type* get_ord() const
+   {
       int ord_size = this->get_ord_size();
       singular_order_type* ord=(singular_order_type*)omalloc0((ord_size+1)*sizeof(singular_order_type));
       ord[1]=ringorder_c;
@@ -198,7 +214,8 @@ public:
       return ord;
    }
 
-   int** get_wvhdl() const {
+   int** get_wvhdl() const
+   {
       int ord_size = this->get_ord_size();
       int** wvhdl=(int**)omalloc0((ord_size+1)*sizeof(int*));
       return wvhdl;
@@ -228,5 +245,4 @@ struct cmp_opaque<polymake::ideal::singular::SingularTermOrderData<OrderType>, v
 
 } }
 
-#endif
 
