@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_CONTAINER_CHAIN_H
-#define POLYMAKE_CONTAINER_CHAIN_H
+#pragma once
 
 #include "polymake/internal/operations.h"
 #include "polymake/ContainerUnion.h"
@@ -1329,7 +1328,6 @@ struct concat_tuple {
 
 } }
 
-#endif // POLYMAKE_CONTAINER_CHAIN_H
 
 // Local Variables:
 // mode:C++
