@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_POLYNOMIALIMPL_H
-#define POLYMAKE_POLYNOMIALIMPL_H
+#pragma once
 
 #include "polymake/Integer.h"
 #include "polymake/Vector.h"
@@ -33,6 +33,36 @@
 #include <forward_list>
 
 namespace pm {
+
+
+template <typename Coefficient, typename Exponent>
+class UniPolynomial;
+template <typename Coefficient, typename Exponent>
+class Polynomial;
+template <typename Coefficient, typename Exponent>
+class RationalFunction;
+
+// some magic needed for operator construction
+struct is_polynomial {};
+
+// forward declarations needed for friends
+template <typename Coefficient, typename Exponent>
+Div< UniPolynomial<Coefficient, Exponent> >
+div(const UniPolynomial<Coefficient, Exponent>& num, const UniPolynomial<Coefficient, Exponent>& den);
+
+template <typename Coefficient, typename Exponent>
+UniPolynomial<Coefficient, Exponent>
+gcd(const UniPolynomial<Coefficient, Exponent>& a, const UniPolynomial<Coefficient, Exponent>& b);
+
+template <typename Coefficient, typename Exponent>
+ExtGCD< UniPolynomial<Coefficient, Exponent> >
+ext_gcd(const UniPolynomial<Coefficient, Exponent>& a, const UniPolynomial<Coefficient, Exponent>& b,
+        bool normalize_gcd=true);
+
+template <typename Coefficient, typename Exponent>
+UniPolynomial<Coefficient, Exponent>
+lcm(const UniPolynomial<Coefficient, Exponent>& a, const UniPolynomial<Coefficient, Exponent>& b);
+
 namespace polynomial_impl {
 
 // how to convert something to a coefficient of a Polynomial ---------------------
@@ -45,17 +75,17 @@ struct deeper_coefficient_impl
 // if T can directly be converted into Polynomial's coefficient, it will be handled by the corresponding constructor
 template <typename T, typename Coefficient>
 struct deeper_coefficient_impl<T, Coefficient,
-                               typename std::enable_if<std::is_convertible<T, Coefficient>::value>::type>
+                               typename std::enable_if_t<std::is_convertible<T, Coefficient>::value>>
 : std::false_type {};
 
 // T can be converted to Polynomial's Coefficient's coefficient
 template <typename T, typename Coefficient>
 struct deeper_coefficient_impl<T, Coefficient,
-                               typename std::enable_if<std::is_convertible<T, typename Coefficient::coefficient_type>::value>::type>
+                               typename std::enable_if_t<std::is_convertible<T, typename Coefficient::coefficient_type>::value>>
 : std::true_type {
   using coefficient_type = Coefficient;
 
-  static coefficient_type construct(const T& x, const int n_vars)
+  static coefficient_type construct(const T& x, const Int n_vars)
   {
     return coefficient_type(x, n_vars);
   }
@@ -64,13 +94,13 @@ struct deeper_coefficient_impl<T, Coefficient,
 // T can be converted to some deeper coefficient in the nesting hierarchy
 template <typename T, typename Coefficient>
 struct deeper_coefficient_impl<T, Coefficient,
-                               typename std::enable_if<!std::is_convertible<T, typename Coefficient::coefficient_type>::value &&
-                                                       deeper_coefficient_impl<T, typename Coefficient::coefficient_type>::value>::type>
+                               typename std::enable_if_t<!std::is_convertible<T, typename Coefficient::coefficient_type>::value &&
+                                                         deeper_coefficient_impl<T, typename Coefficient::coefficient_type>::value>>
 : std::true_type {
   using deeper = deeper_coefficient_impl<T, typename Coefficient::coefficient_type>;
   using coefficient_type = Coefficient;
 
-  static coefficient_type construct(const T& x, const int n_vars)
+  static coefficient_type construct(const T& x, const Int n_vars)
   {
     return coefficient_type(deeper::construct(x, n_vars), n_vars);
   }
@@ -78,7 +108,7 @@ struct deeper_coefficient_impl<T, Coefficient,
 
 // Sorting of monomials ----------------------------------------------
      
-template <typename Exponent=int, bool strict=true>
+template <typename Exponent = Int, bool strict = true>
 class cmp_monomial_ordered_base {
 public:
   // for multi-variate polynomials
@@ -190,25 +220,34 @@ struct nesting_level : int_constant<0> {};
 
 template <typename Exponent>
 struct UnivariateMonomial {
+  template <typename exp>
+  using new_type = UnivariateMonomial<exp>;
   using exponent_type = Exponent;
   using monomial_type = Exponent;
   using monomial_list_type = Vector<Exponent>;
   using homogenized_type = MultivariateMonomial<Exponent>;
   static Exponent deg(const monomial_type& m) { return m; }
-  static monomial_type default_value(const int n_vars) { return zero_value<Exponent>(); }
+  static monomial_type default_value(const Int n_vars) { return zero_value<Exponent>(); }
   static bool equals_to_default(const monomial_type& m) { return is_zero(m); }
 
-  static monomial_type empty_value(const int n_vars)
+  static monomial_type empty_value(const Int n_vars, Int sign = 1)
   {
-    return std::numeric_limits<Exponent>::has_infinity ? - std::numeric_limits<Exponent>::infinity() : std::numeric_limits<Exponent>::min();
+    if (std::numeric_limits<Exponent>::has_infinity)
+      return -sign * std::numeric_limits<Exponent>::infinity();
+    else if (sign > 0)
+      return std::numeric_limits<Exponent>::min();
+    else
+      return std::numeric_limits<Exponent>::max();
   }
-  static void croak_if_incompatible(const monomial_type& m, const int n_vars)
+
+  static void croak_if_incompatible(const monomial_type& m, const Int n_vars)
   {
-    if (n_vars != 1) throw std::runtime_error("Monomial has different number of variables");
+    if (n_vars != 1)
+      throw std::runtime_error("Monomial has different number of variables");
   }
 
   template <typename coefficient_type>
-  static monomial_list_type monomials(const int n_vars, const int n_terms,
+  static monomial_list_type monomials(const Int n_vars, const Int n_terms,
                                       const hash_map<monomial_type, coefficient_type>& h)
   {
     return monomial_list_type(n_terms, attach_operation(h, BuildUnary<operations::take_first>()).begin());
@@ -226,38 +265,40 @@ struct UnivariateMonomial {
     if (!is_one(m)) out << '^' << m;
   }
 
-  static typename homogenized_type::monomial_type homogenize(const monomial_type& m, int new_variable_index, const Exponent& to_degree)
+  static typename homogenized_type::monomial_type homogenize(const monomial_type& m, Int new_variable_index, const Exponent& to_degree)
   {
     typename homogenized_type::monomial_type result(2);
-    result[ new_variable_index? 1 : 0] = to_degree - m;
-    result[ new_variable_index? 0 : 1] = m;
+    result[new_variable_index != 0] = to_degree - m;
+    result[new_variable_index == 0] = m;
     return result;
   }
 };
 
 template <typename Exponent>
 struct MultivariateMonomial {
+  template <typename exp>
+  using new_type = MultivariateMonomial<exp>;
   using exponent_type = Exponent;
   using monomial_type = SparseVector<Exponent>;
   using monomial_list_type = Matrix<Exponent>;
   using homogenized_type = MultivariateMonomial<Exponent>;
   static Exponent deg(const monomial_type& m) { return accumulate(m, operations::add<Exponent, Exponent>()); }
-  static monomial_type default_value(const int n_vars) { return monomial_type(n_vars); }
+  static monomial_type default_value(const Int n_vars) { return monomial_type(n_vars); }
   static bool equals_to_default(const monomial_type& m) { return m.empty(); }
 
-  static monomial_type empty_value(const int n_vars)
-  { 
-    return same_element_vector<Exponent>((std::numeric_limits<Exponent>::has_infinity ? - std::numeric_limits<Exponent>::infinity() : std::numeric_limits<Exponent>::min()),
-                                         n_vars);
+  static monomial_type empty_value(const Int n_vars, Int sign = 1)
+  {
+    return same_element_vector<Exponent>(UnivariateMonomial<Exponent>::empty_value(n_vars, sign), n_vars);
   }
 
-  static void croak_if_incompatible(const monomial_type& m, const int n_vars)
+  static void croak_if_incompatible(const monomial_type& m, const Int n_vars)
   {
-    if (n_vars != m.dim()) throw std::runtime_error("Monomial has different number of variables");
+    if (n_vars != m.dim())
+      throw std::runtime_error("Monomial has different number of variables");
   }
 
   template <typename Coefficient>
-  static monomial_list_type monomials(const int n_vars, const int n_terms,
+  static monomial_list_type monomials(const Int n_vars, const Int n_terms,
                                       const hash_map<monomial_type, Coefficient>& h)
   {
     return monomial_list_type(n_terms, n_vars, 
@@ -285,7 +326,7 @@ struct MultivariateMonomial {
   }
 
   static typename homogenized_type::monomial_type
-  homogenize(const monomial_type& m, int new_variable_index, const Exponent& to_degree)
+  homogenize(const monomial_type& m, Int new_variable_index, const Exponent& to_degree)
   {
     monomial_type result(m.dim()+1);
     result[new_variable_index] = to_degree - deg(m);
@@ -294,15 +335,15 @@ struct MultivariateMonomial {
   }
 };
 
-template <typename T> inline
-typename std::enable_if<is_field<T>::value, bool>::type
+template <typename T>
+std::enable_if_t<is_field<T>::value, bool>
 is_minus_one(const T& x)
 {
   return is_one(-x);
 }
 
-template <typename T> inline
-typename std::enable_if<!is_field<T>::value, bool>::type
+template <typename T>
+std::enable_if_t<!is_field<T>::value, bool>
 is_minus_one(const T& x)
 {
   return false;
@@ -314,6 +355,7 @@ template <typename Monomial, typename Coefficient>
 class GenericImpl {
 
   template <typename> friend struct pm::spec_object_traits;
+  template <typename, typename> friend class GenericImpl;
 
 public:
   using coefficient_type = Coefficient;
@@ -323,7 +365,22 @@ public:
   using term_hash = hash_map<monomial_type, coefficient_type>;
   using monomial_list_type = typename Monomial::monomial_list_type;
 
-  static constexpr int coefficient_nesting_level=nesting_level<coefficient_type>::value;
+
+  friend
+     Div< UniPolynomial<Coefficient, exponent_type> >
+     div<>(const UniPolynomial<Coefficient, exponent_type>& num, const UniPolynomial<Coefficient, exponent_type>& den);
+  friend
+     UniPolynomial<Coefficient, exponent_type>
+     gcd<>(const UniPolynomial<Coefficient, exponent_type>& a, const UniPolynomial<Coefficient, exponent_type>& b);
+  friend
+     ExtGCD< UniPolynomial<Coefficient, exponent_type> >
+     ext_gcd<>(const UniPolynomial<Coefficient, exponent_type>& a, const UniPolynomial<Coefficient, exponent_type>& b,
+           bool normalize_gcd);
+  friend
+     UniPolynomial<Coefficient, exponent_type>
+     lcm<>(const UniPolynomial<Coefficient, exponent_type>& a, const UniPolynomial<Coefficient, exponent_type>& b);
+
+  static constexpr int coefficient_nesting_level = nesting_level<coefficient_type>::value;
 
   template <typename T>
   struct is_deeper_coefficient
@@ -333,12 +390,12 @@ public:
   struct fits_as_coefficient
     : bool_constant<can_upgrade<T, coefficient_type>::value || is_deeper_coefficient<T>::value> {};
 
-  explicit GenericImpl(const int n_vars = 0)
+  explicit GenericImpl(const Int n_vars = 0)
     : n_variables(n_vars)
     , the_sorted_terms_set(false) {}
 
-  template <typename T, typename enabled=typename std::enable_if<fits_as_coefficient<T>::value>::type>
-  GenericImpl(const T& c, const int n_vars)
+  template <typename T, typename = std::enable_if_t<fits_as_coefficient<T>::value>>
+  GenericImpl(const T& c, const Int n_vars)
     : n_variables(n_vars)
     , the_sorted_terms_set(false)
   {
@@ -348,7 +405,7 @@ public:
   }
 
   template <typename Container1, typename Container2>
-  GenericImpl(const Container1& coefficients, const Container2& monomials, const int n_vars)
+  GenericImpl(const Container1& coefficients, const Container2& monomials, const Int n_vars)
     : n_variables(n_vars)
     , the_sorted_terms_set(false)
   {
@@ -361,20 +418,23 @@ public:
       add_term(*m, *c, std::false_type());
   }
 
-  GenericImpl(const int n_vars, const term_hash& src)
+  GenericImpl(const term_hash& src, const Int n_vars)
     : n_variables(n_vars)
     , the_terms(src)
     , the_sorted_terms_set(false) {}
                
-  // Can't have this as constructor, might be ambiguous if coefficient_type = int
-  static GenericImpl fromMonomial(const monomial_type&m, const coefficient_type& c, const int n_vars)
+  GenericImpl(const Int n_vars, const term_hash& src)
+    : GenericImpl(src,n_vars) {}
+
+  // Can't have this as constructor, might be ambiguous if coefficient_type = Int
+  static GenericImpl fromMonomial(const monomial_type&m, const coefficient_type& c, const Int n_vars)
   {
     GenericImpl result(n_vars);
     result.the_terms.insert(m, c);
     return result;
   }
 
-  static GenericImpl fromMonomial(const typename term_hash::const_iterator it, const int n_vars)
+  static GenericImpl fromMonomial(const typename term_hash::const_iterator it, const Int n_vars)
   {
     GenericImpl result(n_vars);
     result.the_terms.insert(it->first, it->second);
@@ -390,23 +450,24 @@ public:
   template <typename Other>
   void croak_if_incompatible(const Other& other) const
   {
-    if (n_vars() != other.n_vars()) throw std::runtime_error("Polynomials of different rings");
+    if (n_vars() != other.n_vars())
+      throw std::runtime_error("Polynomials of different rings");
   }
 
-  int n_vars() const { return n_variables; }
+  const Int& n_vars() const { return n_variables; }
 
-  int n_terms() const { return the_terms.size(); }
+  Int n_terms() const { return the_terms.size(); }
 
   const term_hash& get_terms() const { return the_terms; }
   term_hash& get_mutable_terms() { return the_terms; }
 					
   bool trivial() const { return the_terms.empty(); }
 
-  bool unit() const
+  bool is_one() const
   {
     return the_terms.size()==1
         && Monomial::equals_to_default(the_terms.begin()->first)
-        && is_one(the_terms.begin()->second);
+        && pm::is_one(the_terms.begin()->second);
   }
 
   Vector<coefficient_type> coefficients_as_vector() const
@@ -427,7 +488,7 @@ public:
   }
 
   template <typename T>
-  typename std::enable_if<fits_as_coefficient<T>::value, bool>::type
+  std::enable_if_t<fits_as_coefficient<T>::value, bool>
   operator== (const T& c) const
   {
     return trivial() && is_zero(c)
@@ -459,8 +520,8 @@ public:
 
   typename Monomial::exponent_type lower_deg() const
   {
-    typename Monomial::exponent_type low= Monomial::deg( - Monomial::empty_value(n_variables));
-    for (auto it=entire(get_terms()); !it.at_end(); ++it)
+    typename Monomial::exponent_type low = Monomial::deg(Monomial::empty_value(n_variables, -1));
+    for (auto it = entire(get_terms()); !it.at_end(); ++it)
       assign_min(low, Monomial::deg(it->first));
     return low;
   }
@@ -581,7 +642,7 @@ public:
   }
 
   template <typename T>
-  typename std::enable_if<fits_as_coefficient<T>::value, GenericImpl>::type
+  std::enable_if_t<fits_as_coefficient<T>::value, GenericImpl>
   operator* (const T& c) const
   {
     if (__builtin_expect(is_zero(c), 0))
@@ -591,19 +652,19 @@ public:
   }
 
   template <typename T>
-  typename std::enable_if<fits_as_coefficient<T>::value, GenericImpl>::type
+  std::enable_if_t<fits_as_coefficient<T>::value, GenericImpl>
   mult_from_right(const T& c) const
   {
     if (__builtin_expect(is_zero(c), 0))
       return GenericImpl(n_variables);
     GenericImpl prod(n_variables, the_terms);
     for (auto& term : prod.the_terms)
-      term.second = c * term.second;
+      term.second = c*term.second;
     return prod;
   }
 
   template <typename T>
-  typename std::enable_if<fits_as_coefficient<T>::value, GenericImpl>::type&
+  std::enable_if_t<fits_as_coefficient<T>::value, GenericImpl&>
   operator*= (const T& c)
   {
     if (__builtin_expect(is_zero(c), 0)) {
@@ -616,7 +677,7 @@ public:
   }
 
   template <typename T>
-  typename std::enable_if<fits_as_coefficient<T>::value, GenericImpl>::type
+  std::enable_if_t<fits_as_coefficient<T>::value, GenericImpl>
   operator/ (const T& c) const
   {
     if (__builtin_expect(is_zero(c), 0)) throw GMP::ZeroDivide();
@@ -625,7 +686,7 @@ public:
   }
 
   template <typename T>
-  typename std::enable_if<fits_as_coefficient<T>::value, GenericImpl>::type&
+  std::enable_if_t<fits_as_coefficient<T>::value, GenericImpl&>
   operator/= (const T& c)
   {
     if (__builtin_expect(is_zero(c), 0)) throw GMP::ZeroDivide();
@@ -634,6 +695,20 @@ public:
     return *this;
   }
 
+  GenericImpl div_exact(const GenericImpl& b)
+  {
+    GenericImpl quot;
+    remainder(b, quot);
+    return quot;
+  }
+
+  GenericImpl& operator%= (const GenericImpl& b)
+  {
+      quot_black_hole black_hole;
+      remainder(b, black_hole);
+      return *this;
+  }
+
   //! Divide by the coefficient of the leading monomial
   GenericImpl& normalize()
   {
@@ -644,14 +719,14 @@ public:
     return *this; 
   }
 
-  GenericImpl<typename Monomial::homogenized_type, Coefficient> homogenize(int new_variable_index = 0) const
+  GenericImpl<typename Monomial::homogenized_type, Coefficient> homogenize(Int new_variable_index = 0) const
   {
     const typename Monomial::exponent_type degree = deg();
     hash_map<typename Monomial::homogenized_type::monomial_type, Coefficient> result_hash;
     for (const auto& term : the_terms) {
       result_hash.insert( Monomial::homogenize( term.first, new_variable_index, degree), term.second);
     }
-    return GenericImpl<typename Monomial::homogenized_type, Coefficient>(n_variables + 1, result_hash);
+    return GenericImpl<typename Monomial::homogenized_type, Coefficient>(n_variables+1, result_hash);
   }
 
   GenericImpl operator* (const GenericImpl& p2) const
@@ -672,26 +747,41 @@ public:
   }
 
   template <typename E>
-  GenericImpl exponentiate_monomial(const E& exp) const
+  std::enable_if_t<std::numeric_limits<E>::is_integer, GenericImpl>
+  exponentiate_monomial(const E& exp) const
   {
     if (the_terms.size() != 1)
-      throw std::runtime_error("Except for positive integers, Exponentiation is only implemented for normalized monomials");
+      throw std::runtime_error("exponentiate_monomial: invalid term number");
+    const auto& t = *(the_terms.begin());
+    GenericImpl result(n_variables);
+    result.the_terms.emplace(monomial_type(t.first * exp), pm::pow(t.second,exp));
+    return result;
+  }
+
+  template <typename E>
+  std::enable_if_t<!std::numeric_limits<E>::is_integer, GenericImpl>
+  exponentiate_monomial(const E& exp) const
+  {
+    if (the_terms.size() != 1)
+      throw std::runtime_error("exponentiate_monomial: invalid term number");
     const auto& t = *(the_terms.begin());
     if (t.second != one_value<coefficient_type>())
-      throw std::runtime_error("Except for positive integers, Exponentiation is only implemented for normalized monomials");
+      throw std::runtime_error("Except for integers, Exponentiation is only implemented for normalized monomials");
     GenericImpl result(n_variables);
     result.the_terms.emplace(monomial_type(t.first * exp), t.second);
     return result;
   }
 
   template <typename E>
-  typename std::enable_if<!std::numeric_limits<E>::is_integer, GenericImpl>::type pow(const E& exp) const
+  std::enable_if_t<!std::numeric_limits<E>::is_integer, GenericImpl>
+  pow(const E& exp) const
   {
     return exponentiate_monomial(exp);
   }
 
   template <typename E>
-  typename std::enable_if<std::numeric_limits<E>::is_integer, GenericImpl>::type pow(const E& exp) const
+  std::enable_if_t<std::numeric_limits<E>::is_integer, GenericImpl>
+  pow(const E& exp) const
   {
     if (exp < 0)
       return exponentiate_monomial(exp);
@@ -700,7 +790,7 @@ public:
 
     GenericImpl result(one_value<coefficient_type>(), n_variables);
     if (exp != 0) {
-      int e=exp;
+      long e = exp;
       GenericImpl pow2(*this);
       for (;;) {
         if (e & 1) {
@@ -716,6 +806,16 @@ public:
     return result;
   }
 
+  template <typename Exp=exponent_type, typename T>
+  auto substitute_monomial(const T& exponent) const
+  {
+    typedef typename Monomial::template new_type<Exp> mon;
+    GenericImpl<mon,Coefficient> tmp(n_variables);
+    for (const auto& term : the_terms)
+      tmp.the_terms.emplace(typename mon::monomial_type(convert_to<Exp>(term.first * exponent)), term.second);
+    return tmp;
+  }
+
   GenericImpl operator- () const
   {
     GenericImpl result(n_variables, the_terms);
@@ -730,7 +830,7 @@ public:
   }
 
   template <typename T>
-  typename std::enable_if<fits_as_coefficient<T>::value, GenericImpl>::type
+  std::enable_if_t<fits_as_coefficient<T>::value, GenericImpl>
   operator+ (const T& c) const
   {
     GenericImpl sum(n_variables, the_terms);
@@ -745,14 +845,14 @@ public:
   }
 
   template <typename T>
-  typename std::enable_if<is_deeper_coefficient<T>::value, GenericImpl>::type&
+  std::enable_if_t<is_deeper_coefficient<T>::value, GenericImpl&>
   operator+= (const T& c)
   {
     return operator+=(is_deeper_coefficient<T>::construct(c, n_variables));
   }
 
   template <typename T>
-  typename std::enable_if<fits_as_coefficient<T>::value, GenericImpl>::type
+  std::enable_if_t<fits_as_coefficient<T>::value, GenericImpl>
   operator- (const T& c) const
   {
     GenericImpl diff(n_variables, the_terms);
@@ -767,7 +867,7 @@ public:
   }
 
   template <typename T>
-  typename std::enable_if<is_deeper_coefficient<T>::value, GenericImpl>::type&
+  std::enable_if_t<is_deeper_coefficient<T>::value, GenericImpl&>
   operator-= (const T& c)
   {
     return operator-=(is_deeper_coefficient<T>::construct(c, n_variables));
@@ -839,7 +939,7 @@ public:
   template <typename Output> static
   void pretty_print_term(Output& out, const monomial_type& m, const coefficient_type& c)
   {
-    if (!is_one(c)) {
+    if (!pm::is_one(c)) {
       if (is_minus_one(c)) {
         out << "- ";
       } else {
@@ -926,30 +1026,9 @@ public:
     return compare_ordered(p, cmp_monomial_ordered_base<exponent_type>());
   }
 
-  friend
-  bool operator< (const GenericImpl& p1, const GenericImpl& p2)
-  {
-    return p1.compare(p2) == cmp_lt;
-  }
-  friend
-  bool operator> (const GenericImpl& p1, const GenericImpl& p2)
-  {
-    return p1.compare(p2) == cmp_gt;
-  }
-  friend
-  bool operator<= (const GenericImpl& p1, const GenericImpl& p2)
-  {
-    return p1.compare(p2) != cmp_gt;
-  }
-  friend
-  bool operator>= (const GenericImpl& p1, const GenericImpl& p2)
-  {
-    return p1.compare(p2) != cmp_lt;
-  }
-
   size_t get_hash() const noexcept
   {
-    return hash_func<int>()(n_variables) * hash_func<term_hash>()(the_terms);
+    return hash_func<Int>()(n_variables) * hash_func<term_hash>()(the_terms);
   }
 
   template <typename Order> static 
@@ -1009,6 +1088,57 @@ public:
     return lt_it;
   }
 
+private:
+  struct quot_black_hole
+  {
+    template <bool trusted>
+    void add_term(const monomial_type&, const Coefficient&, bool_constant<trusted>) const {}
+  };
+
+    // replace this with a remainder of division by b, consume the quotient
+  // data must be brought in exclusive posession before calling this method.
+  template <typename QuotConsumer>
+  void remainder(const GenericImpl& b, QuotConsumer& quot_consumer)
+  {
+    const auto b_lead=b.find_lex_lm();
+    typename term_hash::const_iterator this_lead;
+
+    while ((this_lead=find_lex_lm()) != get_mutable_terms().cend() && this_lead->first >= b_lead->first) {
+      const Coefficient k = this_lead->second / b_lead->second;
+      const monomial_type d = this_lead->first - b_lead->first;
+      quot_consumer.add_term(d, k, std::false_type());
+      forget_sorted_terms();
+
+      for (const auto& b_term : b.get_terms()) {
+        auto it = get_mutable_terms().find_or_insert(b_term.first + d);
+        if (it.second) {
+          it.first->second= -k*b_term.second;
+        } else if (is_zero(it.first->second -= k*b_term.second)) {
+          get_mutable_terms().erase(it.first);
+        }
+      }
+    }
+  }
+
+  // replace this with a remainder of division by b, consume the quotient
+  // data must be brought in exclusive posession before calling this method.
+  template <typename QuotConsumer>
+  void remainder(const monomial_type& b, QuotConsumer& quot_consumer)
+  {
+    for (auto it=the_terms.begin(), end=the_terms.end();  it != end;  ) {
+      if (it->first < b) {
+        ++it;
+      } else {
+        if (!std::is_same<QuotConsumer, quot_black_hole>::value)
+          quot_consumer.add_term(it->first - b, it->second, std::false_type());
+        the_terms.erase(it++);
+      }
+    }
+    forget_sorted_terms();
+  }
+
+private:
+
   template <typename T, bool trusted>
   void add_term(const monomial_type& m, T&& c, bool_constant<trusted>)
   {
@@ -1047,8 +1177,7 @@ public:
   }
 
 protected:
-
-  int n_variables;
+  Int n_variables;
   term_hash the_terms;
   // terms ordered by lex termorder 
   mutable sorted_terms_type the_sorted_terms;
@@ -1056,57 +1185,13 @@ protected:
   mutable bool the_sorted_terms_set;
 };
 
+
+template <typename Monomial, typename Coefficient>
+struct impl_chooser {
+  typedef GenericImpl< Monomial, Coefficient> type;
+};
+
 } //end namespace polynomial_impl 
 
-
-template <typename Coefficient, typename Exponent>
-struct spec_object_traits< Serialized< polynomial_impl::GenericImpl<polynomial_impl::UnivariateMonomial<Exponent>, Coefficient> > >
-  : spec_object_traits<is_composite> {
-
-  using Monomial = polynomial_impl::UnivariateMonomial<Exponent>;
-  using masquerade_for = polynomial_impl::GenericImpl<Monomial,Coefficient>;
-
-  using elements = typename polynomial_impl::GenericImpl<Monomial,Coefficient>::term_hash;
-
-  template <typename Me, typename Visitor>
-  static void visit_elements(Me& me, Visitor& v)
-  {
-    // here we read a serialized polynomial and should clear the sorted terms first
-    me.forget_sorted_terms();
-    v << me.the_terms;
-    me.n_variables = 1;
-  }
-
-  template <typename Me, typename Visitor>
-  static void visit_elements(const Me& me, Visitor& v)
-  {
-    v << me.the_terms;
-  }
-};
-
-template <typename Coefficient, typename Exponent>
-struct spec_object_traits< Serialized< polynomial_impl::GenericImpl<polynomial_impl::MultivariateMonomial<Exponent>, Coefficient> > >
-  : spec_object_traits<is_composite> {
-
-  using Monomial = polynomial_impl::MultivariateMonomial<Exponent>;
-  using masquerade_for = polynomial_impl::GenericImpl<Monomial,Coefficient>;
-  using elements = cons<typename polynomial_impl::GenericImpl<Monomial,Coefficient>::term_hash, int>;
-
-  template <typename Me, typename Visitor>
-  static void visit_elements(Me& me, Visitor& v)
-  {
-    // here we read a serialized polynomial and should clear the sorted terms first
-    me.forget_sorted_terms();
-    v << me.the_terms << me.n_variables;
-  }
-
-  template <typename Me, typename Visitor>
-  static void visit_elements(const Me& me, Visitor& v)
-  {
-    v << me.the_terms << me.n_variables;
-  }
-};
-
 } //end namespace pm
 
-#endif // POLYMAKE_POLYNOMIALIMPL_H
