@@ -1,4 +1,4 @@
-/* Copyright (c) 1997-2020
+/* Copyright (c) 1997-2021
    Ewgenij Gawrilow, Michael Joswig, and the polymake team
    Technische Universität Berlin, Germany
    https://polymake.org
@@ -15,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_INTEGER_LINALG_H
-#define POLYMAKE_INTEGER_LINALG_H
+#pragma once
 
 #include "polymake/client.h"
 #include "polymake/SparseMatrix.h"
@@ -157,7 +156,6 @@ using pm::null_space_integer;
 
 }
 
-#endif // POLYMAKE_INTEGER_LINALG_H
 
 // Local Variables:
 // mode:C++
