@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2015
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,18 +15,16 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_INTERNAL_ARRAY_H
-#define POLYMAKE_INTERNAL_ARRAY_H
+#pragma once
 
 namespace pm {
 
 // forward declaration, needed in perl glue code for an explicit specialization.
-template <typename E, typename SharedParams=void>
+template <typename E, typename... SharedParams>
 class Array;
 
 }
 
-#endif // POLYMAKE_INTERNAL_ARRAY_H
 
 // Local Variables:
 // mode:C++
