@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,8 +15,7 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_INTERNAL_ASSOC_H
-#define POLYMAKE_INTERNAL_ASSOC_H
+#pragma once
 
 #include <stdexcept>
 
@@ -143,10 +143,14 @@ struct operation_cross_const_helper< operations::associative_search<TMapRef> > {
 };
 
 template <typename TMap, typename TKeys,
+          bool is_multimap=TMap::is_multimap,
           bool keys_match=isomorphic_types<typename TMap::key_type, TKeys>::value>
-class assoc_helper {
+class assoc_helper {};
+
+template <typename TMap, typename TKeys>
+class assoc_helper<TMap, TKeys, false, true> {
 public:
-   typedef typename inherit_const<typename TMap::mapped_type, TMap>::type& result_type;
+   using result_type = typename inherit_const<typename TMap::mapped_type, TMap>::type&;
 
    result_type operator()(TMap& map, const TKeys& k) const
    {
@@ -168,19 +172,19 @@ protected:
 };
 
 template <typename TMap, size_t s>
-class assoc_helper<TMap, char[s], true>
-   : assoc_helper<TMap, typename TMap::key_type, true> {
+class assoc_helper<TMap, char[s], false, true>
+   : assoc_helper<TMap, typename TMap::key_type, false, true> {
 public:
-   typedef assoc_helper<TMap, typename TMap::key_type, true> base_t;
+   using base_t = assoc_helper<TMap, typename TMap::key_type, false, true>;
 
    typename base_t::result_type operator()(TMap& map, const char (&k)[s]) const
    {
-      return base_t::impl(map, typename TMap::key_type(k), std::is_const<TMap>());
+      return base_t::operator()(map, typename TMap::key_type(k));
    }
 };
 
 template <typename TMap, typename TKeys>
-class assoc_helper<TMap, TKeys, false> {
+class assoc_helper<TMap, TKeys, false, false> {
 public:
    typedef TransformedContainer<const TKeys&, operations::associative_access<TMap&, typename TKeys::value_type> > result_type;
 
@@ -190,7 +194,7 @@ public:
    }
 };
 
-template <typename TMap, typename TKeys> inline
+template <typename TMap, typename TKeys>
 typename assoc_helper<const TMap, TKeys>::type
 select_by_keys(const TMap& map, const TKeys& keys)
 {
@@ -216,7 +220,7 @@ struct hash_func<TMap, is_map> {
       size_t a(1);
       // we cannot depend on the keys being visited in any particular order because
       // the Map might be a hash_map, so we need a commutative and associative operation
-      for (const auto e : m)
+      for (const auto& e : m)
          a += key_hasher(e.first) + mapped_hasher(e.second);
       return a;
    }
@@ -233,7 +237,6 @@ using pm::DefaultValueTag;
 using pm::no_match;
 }
 
-#endif // POLYMAKE_INTERNAL_ASSOC_H
 
 // Local Variables:
 // mode:C++
