@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2021
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -14,12 +15,12 @@
 --------------------------------------------------------------------------------
 */
 
-#ifndef POLYMAKE_PERL_ASSOC_H
-#define POLYMAKE_PERL_ASSOC_H
+#pragma once
 
 #include "polymake/internal/iterators.h"
 #include "polymake/perl/constants.h"
 #include "polymake/perl/Value.h"
+#include "polymake/optional"
 
 namespace pm { namespace perl {
 
@@ -35,7 +36,7 @@ public:
 template <typename Container>
 class element_finder_helper<Container, false> {
 protected:
-   typename Entire<Container>::iterator pos;
+   typename ensure_features<Container, end_sensitive>::iterator pos;
 public:
    element_finder_helper(Container& c, typename container_traits<Container>::iterator where)
       : pos(entire(c)) { pos=where; }
@@ -43,19 +44,22 @@ public:
 
 template <typename Container>
 class element_finder
-   : protected element_finder_helper<const Container>
-   , public MaybeUndefined< element_finder<Container> > {
+   : protected element_finder_helper<const Container> {
 public:
    template <typename Key>
    element_finder(const Container& c, const Key& key)
       : element_finder_helper<const Container>(c, c.find(key)) {}
 
-   bool defined() const { return !this->pos.at_end(); }
+   explicit operator bool() const noexcept { return !this->pos.at_end(); }
 
-   decltype(auto) get_val() const { return this->pos->second; }
+   const auto& value() const { return this->pos->second; }
 };
 
-template <typename Container, typename Key> inline
+template <typename Container>
+struct is_optional_value<element_finder<Container>>
+   : std::true_type {};
+
+template <typename Container, typename Key>
 element_finder<Container> find_element(const Container& c, const Key& key)
 {
    return element_finder<Container>(c, key);
@@ -63,27 +67,31 @@ element_finder<Container> find_element(const Container& c, const Key& key)
 
 template <typename Container>
 class delayed_eraser
-   : protected element_finder_helper<Container>
-   , public MaybeUndefined< delayed_eraser<Container> > {
+   : protected element_finder_helper<Container> {
 public:
    template <typename Key>
    delayed_eraser(Container& c_arg, const Key& key)
       : element_finder_helper<Container>(c_arg, c_arg.find(key))
       , c(c_arg) {}
 
-   bool defined() const { return !this->pos.at_end(); }
+   explicit operator bool() const noexcept { return !this->pos.at_end(); }
 
-   decltype(auto) get_val() const { return std::move(this->pos->second); }
+   decltype(auto) value() const { return std::move(this->pos->second); }
 
    ~delayed_eraser()
    {
-      if (defined()) c.erase(this->pos);
+      if (operator bool()) c.erase(this->pos);
    }
+
 private:
    Container& c;
 };
 
-template <typename Container, typename Key> inline
+template <typename Container>
+struct is_optional_value<delayed_eraser<Container>>
+   : std::true_type {};
+
+template <typename Container, typename Key>
 delayed_eraser<Container> delayed_erase(Container& c, const Key& key)
 {
    return delayed_eraser<Container>(c, key);
@@ -91,7 +99,6 @@ delayed_eraser<Container> delayed_erase(Container& c, const Key& key)
 
 } }
 
-#endif // POLYMAKE_PERL_ASSOC_H
 
 // Local Variables:
 // mode:C++
