@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2024
+#  Copyright (c) 1997-2021
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -30,11 +30,6 @@ use Polymake::Struct (
 
 sub new {
    my $self = &_new;
-   if ($self->type eq "ANY_DATA_TYPE" and
-       defined($self->paths) || !is_code($self->body)) {
-      croak("ANY_DATA_TYPE rule must have a body and no property path");
-   }
-
    $self->paths &&= [ map { [ split /\./ ] } split /\s*\|\s*/, $self->paths ];
 
    unless (is_code($self->body)) {
