@@ -1,4 +1,4 @@
-#  Copyright (c) 1997-2024
+#  Copyright (c) 1997-2021
 #  Ewgenij Gawrilow, Michael Joswig, and the polymake team
 #  Technische Universität Berlin, Germany
 #  https://polymake.org
@@ -316,7 +316,7 @@ sub rel_symlink {
    my $rel_link = $link;
    my $common_prefix = 1;
    while ($rel_link =~ s{^(/[^/]+)(?=/)}{}) {
-      if ($common_prefix && substr($target, 0, length($1)+1) eq "$1/") {
+      if ($common_prefix && substr($target, 0, length($1)) eq $1) {
          $target = substr($target, length($1));
       } else {
          $common_prefix = 0;
@@ -589,7 +589,7 @@ sub install_bin_scripts {
       s{^\#!\S+}{#!$Config::Config{perlpath}}s;
    }
 
-   s{=Version(?=;)}{="$Version"};
+   s{=Version(?=;)}{=$Version};
    s{=InstallTop(?=;)}{='$ConfigFlags{InstallTop}'};
    s{=InstallArch(?=;)}{='$ConfigFlags{InstallArch}'};
 
